==> wordpress_0.6.97-2.tar.gz: wordpress-0.6.97/src/wppagegraphicslist.h <==
/*
 * wpcollectiongraphicslist.h
 *
 *  Created on: 19.5.2010
 *      Author: jlep
 */

#ifndef WPPAGEGRAPHICSLIST_H_
#define WPPAGEGRAPHICSLIST_H_

#include <QGraphicsWidget>
#include <QGraphicsView>
#include <QList>

#include "WPData.h"
#include "busyindicator.h"
#include "themedatastorage.h"

class QLabel;
class QPushButton;
class QPropertyAnimation;
class WPPageGraphicsListItem;

class PopupMenu;
class PageGraphicsView;
class WPPageGraphicsListItem;
class QGraphicsProxyWidget;
class QGraphicsLinearLayout;
class PannableView;
class BlogView;
class WPKeyDispatcher;

class WPPageGraphicsList  : public QGraphicsWidget
{
    Q_OBJECT

public:
    enum TMenuAction
    {
    	EOpen,
    	EEdit,
    	EDelete
    };

    WPPageGraphicsList(QListIterator<WPPage> aPages, const QGraphicsView& aGraphicsView,
        BlogView* aBlogView, PannableView* aPannableView);
    ~WPPageGraphicsList();

public:
    const QFont& titleFont() const { return iTitleFont; };
    const QFont& authorFont() const { return iAuthorFont; };
    const QFont& infoFont() const { return iInfoFont; };
    void setFocus();

public slots:
    void PageChanged(WPPage aPage);
    void PageRemoved(WPPage aPage);
    void PageAdded(WPPage aPage);

signals:
    void OpenClicked(WPPage aPage);
    void EditClicked(WPPage aPage);
    
private:
    void AddPage(WPPage aPage);
    void RemovePage (WPPage aPage);
   
    void SetLabelText();
    
    void DecrementDrafts();
    void DecrementPages();
    
    void IncrementDrafts();
    void IncrementPages();


    void resizeEvent(QGraphicsSceneResizeEvent *e);

private slots:
    void Open();
    void Edit();
    void Delete();

public slots:
    void MenuHiding();
    void ShowContextMenu(WPPageGraphicsListItem* aItem, QPoint aPos);
    void ContextMenuHidden();

private:
   QPoint getMenuLocation(QPoint itemPoint);
   void keyPressEvent( QKeyEvent * event  );
   void keyReleaseEvent( QKeyEvent * event );

private: // Data
    QString iTitle;
    WPNetworkEngine& iNetworkEngine;
    const QGraphicsView& iGraphicsView;
    WPKeyDispatcher* iKeyDispatcher;

    QList<WPPageGraphicsListItem*> iItems;
    WPPageGraphicsListItem* iCurrentItem;
    QGraphicsLinearLayout* iLayout;

    QLabel* iDraftsLabel;
    QGraphicsProxyWidget* iDraftsProxy;
    QLabel* iPagesLabel;
    QGraphicsProxyWidget* iPagesProxy;
    int iDrafts;
    int iPages;

    QAction* iActionOpen;
    QAction* iActionEdit;
    QAction* iActionDelete;
    int iStretchCount;
    PopupMenu* iPopupMenu;
    QPropertyAnimation* iAnimation;
    
    QPushButton* iNewPageButton;
    QGraphicsProxyWidget* iNewPageProxy;
    
    QGraphicsProxyWidget* iMenuProxy;
    
    BusyIndicator& iBusyIndicator;
    QFont iTitleFont;
    QFont iAuthorFont;
    QFont iInfoFont;
    bool  iMenuHiding;
    ThemeData& iThemeData;
    PannableView* iPannableView;
};

#endif /* WPPAGEGRAPHICSLIST_H_ */

==> wordpress_0.6.98.tar.gz: wordpress-0.6.98/src/wppagegraphicslist.h <==
/*
 * wpcollectiongraphicslist.h
 *
 *  Created on: 19.5.2010
 *      Author: jlep
 */

#ifndef WPPAGEGRAPHICSLIST_H_
#define WPPAGEGRAPHICSLIST_H_

#include <QGraphicsWidget>
#include <QGraphicsView>
#include <QList>

#include "WPData.h"
#include "busyindicator.h"
#include "themedatastorage.h"

class QLabel;
class QPushButton;
class QPropertyAnimation;
class WPPageGraphicsListItem;

class PopupMenu;
class PageGraphicsView;
class WPGraphicsListItem;
class WPPageGraphicsListItem;
class QGraphicsProxyWidget;
class QGraphicsLinearLayout;
class PannableView;
class BlogView;
class WPKeyDispatcher;

class WPPageGraphicsList  : public QGraphicsWidget
{
    Q_OBJECT

public:
    enum TMenuAction
    {
    	EOpen,
    	EEdit,
    	EDelete
    };

    WPPageGraphicsList(QListIterator<WPPage> aPages, const QGraphicsView& aGraphicsView,
        BlogView* aBlogView, PannableView* aPannableView);
    ~WPPageGraphicsList();

public:
    const QFont& titleFont() const { return iTitleFont; };
    const QFont& authorFont() const { return iAuthorFont; };
    const QFont& infoFont() const { return iInfoFont; };
    void setFocus();

public slots:
    void PageChanged(WPPage aPage);
    void PageRemoved(WPPage aPage);
    void PageAdded(WPPage aPage);

signals:
    void OpenClicked(WPPage aPage);
    void EditClicked(WPPage aPage);
    
private:
    void AddPage(WPPage aPage);
    void RemovePage (WPPage aPage);
   
    void SetLabelText();
    
    void DecrementDrafts();
    void DecrementPages();
    
    void IncrementDrafts();
    void IncrementPages();


    void resizeEvent(QGraphicsSceneResizeEvent *e);

private slots:
    void Open();
    void Edit();
    void Delete();

public slots:
    void MenuHiding();
    void ShowContextMenu(WPGraphicsListItem* aItem, QPoint aPos);
    void ContextMenuHidden();

private:
   QPoint getMenuLocation(QPoint itemPoint);
   void keyPressEvent( QKeyEvent * event  );
   void keyReleaseEvent( QKeyEvent * event );

private: // Data
    QString iTitle;
    WPNetworkEngine& iNetworkEngine;
    const QGraphicsView& iGraphicsView;
    WPKeyDispatcher* iKeyDispatcher;

    QList<WPPageGraphicsListItem*> iItems;
    WPPageGraphicsListItem* iCurrentItem;
    QGraphicsLinearLayout* iLayout;

    QLabel* iDraftsLabel;
    QGraphicsProxyWidget* iDraftsProxy;
    QLabel* iPagesLabel;
    QGraphicsProxyWidget* iPagesProxy;
    int iDrafts;
    int iPages;

    QAction* iActionOpen;
    QAction* iActionEdit;
    QAction* iActionDelete;
    int iStretchCount;
    PopupMenu* iPopupMenu;
    QPropertyAnimation* iAnimation;
    
    QPushButton* iNewPageButton;
    QGraphicsProxyWidget* iNewPageProxy;
    
    QGraphicsProxyWidget* iMenuProxy;
    
    BusyIndicator& iBusyIndicator;
    QFont iTitleFont;
    QFont iAuthorFont;
    QFont iInfoFont;
    bool  iMenuHiding;
    ThemeData& iThemeData;
    PannableView* iPannableView;
};

#endif /* WPPAGEGRAPHICSLIST_H_ */
